#[repr(u8)]pub enum SeqStat {
NO_DATA_PIN_CONN = 0,
DATA_PIN_CONN = 1,
CP_DET_DONE = 2,
CT_DET_DONE = 3,
}Variants
NO_DATA_PIN_CONN = 0
The module is either not enabled, or the module is enabled but the data pins have not yet been detected.
DATA_PIN_CONN = 1
Data pin contact detection is complete.
CP_DET_DONE = 2
Charging port detection is complete.
CT_DET_DONE = 3
Charger type detection is complete.
Implementations